==> camel-hazelcast-2.7.2-sources.jar: org/apache/camel/component/hazelcast/queue/HazelcastQueueEndpoint.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.hazelcast.queue;

import org.apache.camel.Component;
import org.apache.camel.Consumer;
import org.apache.camel.Processor;
import org.apache.camel.Producer;
import org.apache.camel.component.hazelcast.HazelcastDefaultEndpoint;

/**
 *
 */
public class HazelcastQueueEndpoint extends HazelcastDefaultEndpoint {

    public HazelcastQueueEndpoint(String endpointUri, Component component, String cacheName) {
        super(endpointUri, component, cacheName);
    }

    @Override
    public Consumer createConsumer(Processor processor) throws Exception {
        return new HazelcastQueueConsumer(this, processor, cacheName);
    }

    @Override
    public Producer createProducer() throws Exception {
        return new HazelcastQueueProducer(this, cacheName);
    }

}

==> camel-hazelcast-2.11.0-sources.jar: org/apache/camel/component/hazelcast/queue/HazelcastQueueEndpoint.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.hazelcast.queue;

import com.hazelcast.core.HazelcastInstance;
import org.apache.camel.Component;
import org.apache.camel.Consumer;
import org.apache.camel.Processor;
import org.apache.camel.Producer;
import org.apache.camel.component.hazelcast.HazelcastDefaultEndpoint;

/**
 *
 */
public class HazelcastQueueEndpoint extends HazelcastDefaultEndpoint {

    public HazelcastQueueEndpoint(HazelcastInstance hazelcastInstance, String endpointUri, Component component, String cacheName) {
        super(hazelcastInstance, endpointUri, component, cacheName);
    }

    @Override
    public Consumer createConsumer(Processor processor) throws Exception {
        return new HazelcastQueueConsumer(hazelcastInstance, this, processor, cacheName);
    }

    @Override
    public Producer createProducer() throws Exception {
        return new HazelcastQueueProducer(hazelcastInstance, this, cacheName);
    }

}
